COMPMID-415: Move ConvolutionLayer to new validation

Change-Id: I1f40dff43142c4e2c096122bfa1ca08241ff80ff
Reviewed-on: http://mpd-gerrit.cambridge.arm.com/81952
Tested-by: Kaizen <jeremy.johnson+kaizengerrit@arm.com>
Reviewed-by: Anthony Barbier <anthony.barbier@arm.com>
diff --git a/tests/datasets_new/ShapeDatasets.h b/tests/datasets_new/ShapeDatasets.h
index ba142ca..14f7851 100644
--- a/tests/datasets_new/ShapeDatasets.h
+++ b/tests/datasets_new/ShapeDatasets.h
@@ -35,7 +35,7 @@
 {
 namespace datasets
 {
 /** Data set containing one 1D tensor shape. */
 class Small1DShape final : public framework::dataset::SingletonDataset<TensorShape>
 {
 public:
@@ -48,7 +48,7 @@
 /** Parent type for all for shape datasets. */
 using ShapeDataset = framework::dataset::ContainerDataset<std::vector<TensorShape>>;
 
-/** Data set containing two small 2D tensor shapes. */
+/** Data set containing small 2D tensor shapes. */
 class Small2DShapes final : public ShapeDataset
 {
 public:
@@ -93,7 +93,7 @@
     }
 };
 
-/** Data set containing two 2D large tensor shapes. */
+/** Data set containing large 2D tensor shapes. */
 class Large2DShapes final : public ShapeDataset
 {
 public:
@@ -107,6 +107,21 @@
     {
     }
 };
+
+/** Data set containing small tensor shapes for direct convolution. */
+class SmallDirectConvolutionShapes final : public ShapeDataset
+{
+public:
+    SmallDirectConvolutionShapes()
+        : ShapeDataset("InputShape",
+    {
+        TensorShape{ 3U, 3U, 3U, 2U, 4U, 5U },
+                     TensorShape{ 32U, 37U, 3U },
+                     TensorShape{ 13U, 15U, 8U, 3U }
+    })
+    {
+    }
+};
 } // namespace datasets
 } // namespace test
 } // namespace arm_compute
@@ -35,7 +35,7 @@
 namespace datasets
 {
-/** Data set containing one 1D tensor shape. */
+/** Data set containing 1D tensor shapes. */
 class Small1DShape final : public framework::dataset::SingletonDataset<TensorShape>
 {